@@ -98,6 +98,8 @@ class CiscoCompiler(PlatformCompiler):
 # TODO: merge common router code, so end up with three loops: routers, ios
 # routers, ios_xr routers
 
+    #TODO: Split out each device compiler into own function
+
         # store autonetkit_cisco version
         from pkg_resources import get_distribution
         ank_cisco_version = get_distribution("autonetkit_cisco").version
@@ -127,30 +129,38 @@ class CiscoCompiler(PlatformCompiler):
                 if phy_specified_id is not None:
                     interface.id = phy_specified_id
 
-        from autonetkit.compilers.device.ubuntu import UbuntuCompiler
+        #from autonetkit.compilers.device.ubuntu import UbuntuCompiler
+        from autonetkit_cisco.compilers.device.ubuntu import UbuntuCompiler
+
         ubuntu_compiler = UbuntuCompiler(self.nidb, self.anm)
         for phy_node in g_phy.nodes('is_server', host=self.host):
-            #TODO: look at server syntax also, same as for routers
             nidb_node = self.nidb.node(phy_node)
+
+            #TODO: look at server syntax also, same as for routers
             for interface in nidb_node.physical_interfaces:
-                interface.id = self.numeric_to_interface_label_linux(interface.numeric_id)
+                phy_specified_id = phy_node.interface(interface).specified_id
+                if phy_specified_id is not None:
+                    interface.id = phy_specified_id
+
+                #interface.id = self.numeric_to_interface_label_linux(interface.numeric_id)
+                #print "numeric", interface.numeric_id, interface.id
                 nidb_node.ip.use_ipv4 = phy_node.use_ipv4
                 nidb_node.ip.use_ipv6 = phy_node.use_ipv6
-                phy_int = phy_node.interface(interface)
 
                 #TODO: clean up interface handling
-                numeric_int_ids = self.numeric_interface_ids()
-                for interface in nidb_node.physical_interfaces:
-                    phy_numeric_id = phy_node.interface(interface).numeric_id
-                    if phy_numeric_id is None:
-                        #TODO: remove numeric ID code
-                        interface.numeric_id = numeric_int_ids.next()
-                    else:
-                        interface.numeric_id = int(phy_numeric_id)
+            numeric_int_ids = self.numeric_interface_ids()
+            for interface in nidb_node.physical_interfaces:
+                phy_int = phy_node.interface(interface)
+                phy_numeric_id = phy_node.interface(interface).numeric_id
+                if phy_numeric_id is None:
+                    #TODO: remove numeric ID code
+                    interface.numeric_id = numeric_int_ids.next()
+                else:
+                    interface.numeric_id = int(phy_numeric_id)
 
-                    phy_specified_id = phy_node.interface(interface).specified_id
-                    if phy_specified_id is not None:
-                        interface.id = phy_specified_id
+                phy_specified_id = phy_node.interface(interface).specified_id
+                if phy_specified_id is not None:
+                    interface.id = phy_specified_id
 
                 #TODO: make this part of the base device compiler, which server/router inherits
                 if nidb_node.ip.use_ipv4:
@@ -172,6 +182,11 @@ class CiscoCompiler(PlatformCompiler):
                         interface.ipv6_address = sn_preflen_to_network(ipv6_int.ip_address,
                                 interface.ipv6_subnet.prefixlen)
 
+            if use_mgmt_interfaces: # not these are physical interfaces; configure after previous config steps
+                mgmt_int = nidb_node.add_interface(management = True)
+                mgmt_int_id = "eth0"
+                mgmt_int.id = mgmt_int_id
+
                     # render route config
             nidb_node = self.nidb.node(phy_node)
             ubuntu_compiler.compile(nidb_node)
@@ -216,7 +231,12 @@ class CiscoCompiler(PlatformCompiler):
                 numeric_to_interface_label = self.numeric_to_interface_label_ios
 
             if use_mgmt_interfaces:
-                mgmt_int_id = int_ids.next()  # 0/0 is used for management ethernet
+                if phy_node.device_subtype == "vios":
+                    #TODO: make these configured in the internal config file
+                    # for platform/device_subtype keying
+                    mgmt_int_id = "GigabitEthernet0/0"
+                if phy_node.device_subtype == "CSR1000v":
+                    mgmt_int_id = "GigabitEthernet0"
 
             for interface in nidb_node.physical_interfaces:
                 #TODO: use this code block once for all routers
